@@ -102,3 +102,8 @@ class BackupsClient(rest_client.RestClient):
         except lib_exc.NotFound:
             return True
         return False
+
+    @property
+    def resource_type(self):
+        """Returns the primary type of resource this client works with."""
+        return 'backup'
